# compiles new post into target directory
post() {
	# check directory existence
	if [ -f markdown/post/$1 ] 
	then
		# compile the new post and drop it in ./post/
		pandoc markdown/post/$1 --css bstyle.css -s -o post/${1%.*}.html
	else
		# error message incase file was not found
		echo "File \"$1\" not found in markdown/post"
	fi
}

# mainly to create new post files
writep() {
	if [ -z $1 ]
	then
		echo 'No filename given' 
		exit 0
	fi
	cp ./markdown/template.md ./markdown/post/$1
	vim -c "Goyo" ./markdown/post/$1
}

page() {
	# we want to enforce maintainence of directory structure
	if [ -f markdown/pages/$1 ] 
	then
		pandoc markdown/pages/$1 --css bstyle.css -s -o page/${1%.*}.html
	else
		echo "File \"$1\" not found in markdown/pages"
	fi
}

# literally just updates the index file nothing else
index() {
	pandoc ./markdown/index.md --css style.css -s -o index.html # typing succs
}

help() {
	case $1 in 
		type)
			echo -e "[post, page] \n\tThe kind of page you want to add to the site"
			echo "Different types result in different compilation locations"
			;;
		target)
			echo "The file that you want to actually compile to html"
			;;
		flag)
			echo -e "Available flags:\n\tr - rebuilds file, does not update index.html\n\tn - builds file, updates index.html"
			echo -e "\t*Pages will not update index.html*"
			;;
		*)
			echo "./make.sh type target.md flag"
	esac
}

# taking function names as para
"$@"
